@@ -66,14 +66,14 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import aws_cdk.aws_certificatemanager
-import aws_cdk.aws_route53
-import aws_cdk.core
-import constructs
+import aws_cdk.aws_certificatemanager as _aws_cdk_aws_certificatemanager_1662be0d
+import aws_cdk.aws_route53 as _aws_cdk_aws_route53_f47b29d4
+import aws_cdk.core as _aws_cdk_core_f4b25747
+import constructs as _constructs_77d1e7e8
 
 
 class HttpsRedirect(
-    aws_cdk.core.Construct,
+    _aws_cdk_core_f4b25747.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-cdk/aws-route53-patterns.HttpsRedirect",
 ):
@@ -97,12 +97,12 @@ class HttpsRedirect(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
         target_domain: builtins.str,
-        zone: aws_cdk.aws_route53.IHostedZone,
-        certificate: typing.Optional[aws_cdk.aws_certificatemanager.ICertificate] = None,
+        zone: _aws_cdk_aws_route53_f47b29d4.IHostedZone,
+        certificate: typing.Optional[_aws_cdk_aws_certificatemanager_1662be0d.ICertificate] = None,
         record_names: typing.Optional[typing.Sequence[builtins.str]] = None,
     ) -> None:
         '''
@@ -114,17 +114,7 @@ class HttpsRedirect(
         :param record_names: The domain names that will redirect to ``targetDomain``. Default: - the domain name of the hosted zone
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                id: builtins.str,
-                *,
-                target_domain: builtins.str,
-                zone: aws_cdk.aws_route53.IHostedZone,
-                certificate: typing.Optional[aws_cdk.aws_certificatemanager.ICertificate] = None,
-                record_names: typing.Optional[typing.Sequence[builtins.str]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__c167914f42b51e85103f28c6effb1b92951aab4a7882d6c3fc32b9f86400b1d6)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = HttpsRedirectProps(
@@ -152,8 +142,8 @@ class HttpsRedirectProps:
         self,
         *,
         target_domain: builtins.str,
-        zone: aws_cdk.aws_route53.IHostedZone,
-        certificate: typing.Optional[aws_cdk.aws_certificatemanager.ICertificate] = None,
+        zone: _aws_cdk_aws_route53_f47b29d4.IHostedZone,
+        certificate: typing.Optional[_aws_cdk_aws_certificatemanager_1662be0d.ICertificate] = None,
         record_names: typing.Optional[typing.Sequence[builtins.str]] = None,
     ) -> None:
         '''Properties to configure an HTTPS Redirect.
@@ -177,20 +167,12 @@ class HttpsRedirectProps:
             )
         '''
         if __debug__:
-            def stub(
-                *,
-                target_domain: builtins.str,
-                zone: aws_cdk.aws_route53.IHostedZone,
-                certificate: typing.Optional[aws_cdk.aws_certificatemanager.ICertificate] = None,
-                record_names: typing.Optional[typing.Sequence[builtins.str]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__cd8569f0c313942c16b27a760e18cefe3d90cc6e044d863ff7b3c0616331530f)
             check_type(argname="argument target_domain", value=target_domain, expected_type=type_hints["target_domain"])
             check_type(argname="argument zone", value=zone, expected_type=type_hints["zone"])
             check_type(argname="argument certificate", value=certificate, expected_type=type_hints["certificate"])
             check_type(argname="argument record_names", value=record_names, expected_type=type_hints["record_names"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "target_domain": target_domain,
             "zone": zone,
         }
@@ -212,7 +194,7 @@ class HttpsRedirectProps:
         return typing.cast(builtins.str, result)
 
     @builtins.property
-    def zone(self) -> aws_cdk.aws_route53.IHostedZone:
+    def zone(self) -> _aws_cdk_aws_route53_f47b29d4.IHostedZone:
         '''Hosted zone of the domain which will be used to create alias record(s) from domain names in the hosted zone to the target domain.
 
         The hosted zone must
@@ -224,12 +206,12 @@ class HttpsRedirectProps:
         '''
         result = self._values.get("zone")
         assert result is not None, "Required property 'zone' is missing"
-        return typing.cast(aws_cdk.aws_route53.IHostedZone, result)
+        return typing.cast(_aws_cdk_aws_route53_f47b29d4.IHostedZone, result)
 
     @builtins.property
     def certificate(
         self,
-    ) -> typing.Optional[aws_cdk.aws_certificatemanager.ICertificate]:
+    ) -> typing.Optional[_aws_cdk_aws_certificatemanager_1662be0d.ICertificate]:
         '''The AWS Certificate Manager (ACM) certificate that will be associated with the CloudFront distribution that will be created.
 
         If provided, the certificate must be
@@ -238,7 +220,7 @@ class HttpsRedirectProps:
         :default: - A new certificate is created in us-east-1 (N. Virginia)
         '''
         result = self._values.get("certificate")
-        return typing.cast(typing.Optional[aws_cdk.aws_certificatemanager.ICertificate], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_certificatemanager_1662be0d.ICertificate], result)
 
     @builtins.property
     def record_names(self) -> typing.Optional[typing.List[builtins.str]]:
@@ -267,3 +249,25 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__c167914f42b51e85103f28c6effb1b92951aab4a7882d6c3fc32b9f86400b1d6(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    target_domain: builtins.str,
+    zone: _aws_cdk_aws_route53_f47b29d4.IHostedZone,
+    certificate: typing.Optional[_aws_cdk_aws_certificatemanager_1662be0d.ICertificate] = None,
+    record_names: typing.Optional[typing.Sequence[builtins.str]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__cd8569f0c313942c16b27a760e18cefe3d90cc6e044d863ff7b3c0616331530f(
+    *,
+    target_domain: builtins.str,
+    zone: _aws_cdk_aws_route53_f47b29d4.IHostedZone,
+    certificate: typing.Optional[_aws_cdk_aws_certificatemanager_1662be0d.ICertificate] = None,
+    record_names: typing.Optional[typing.Sequence[builtins.str]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
